[telepathy-gabble/master] test-disco-no-reply: subclass the XmppXmlStream instead of the JabberXmlStream so it can be used with the XmppAuthenticator

Guillaume Desmottes guillaume.desmottes at collabora.co.uk
Wed Jul 1 04:16:14 PDT 2009


---
 tests/twisted/test-disco-no-reply.py |    6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diff --git a/tests/twisted/test-disco-no-reply.py b/tests/twisted/test-disco-no-reply.py
index 2b3b010..1e33e43 100644
--- a/tests/twisted/test-disco-no-reply.py
+++ b/tests/twisted/test-disco-no-reply.py
@@ -4,7 +4,7 @@ Test that Gabble disconnects connection if it doesn't receive a response
 to its service discovery request
 """
 
-from gabbletest import exec_test, JabberXmlStream
+from gabbletest import exec_test, XmppXmlStream
 
 def test(q, bus, conn, stream):
     conn.Connect()
@@ -15,8 +15,8 @@ def test(q, bus, conn, stream):
     # disco request timed out
     q.expect('dbus-signal', signal='StatusChanged', args=[2, 2])
 
-class JabberXmlStreamNoDiscoReply (JabberXmlStream):
-    """Subclass JabberXmlStream to don't automatically send a disco reply"""
+class JabberXmlStreamNoDiscoReply (XmppXmlStream):
+    """Subclass XmppXmlStream to don't automatically send a disco reply"""
     def _cb_disco_iq (self, iq):
         pass
 
-- 
1.5.6.5




More information about the telepathy-commits mailing list